==> foundation-2.6.1.tgz: package/Dollar/Dollar.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Dollar = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M54.284 44.798v-10.11c3.297.807 6.52 2.344 9.157 4.762l.011-.015c.197.157.436.265.708.265.358 0 .665-.173.877-.428l.015.003 4.262-6.008-.01-.005c.175-.202.291-.458.291-.746 0-.34-.153-.638-.387-.849-3.953-3.651-9-5.843-14.924-6.502v-5.806h-.001c0-.637-.516-1.153-1.153-1.153h-4.578c-.637 0-1.153.516-1.153 1.153v5.659c-9.89 1.025-15.75 7.326-15.75 14.725 0 9.963 8.205 12.82 15.75 14.652v11.354c-4.845-.868-8.827-3.379-11.536-6.19-.019-.021-.039-.039-.06-.058l-.052-.051-.008.011a1.134 1.134 0 00-.719-.273 1.14 1.14 0 00-.998.608l-.014-.002-4.125 6.124.005.01a1.133 1.133 0 00-.292.748c0 .367.182.679.448.89l-.011.016c4.029 4.029 9.67 6.959 17.362 7.619v5.44c0 .637.516 1.153 1.153 1.153h4.578c.637 0 1.153-.517 1.153-1.153h.001V75.2c10.769-1.1 16.117-7.398 16.117-15.531 0-10.035-8.498-12.967-16.117-14.871zm-6.886-1.686c-3.003-.951-5.055-2.051-5.055-4.176 0-2.49 1.832-4.248 5.055-4.688v8.864zm6.886 22.784V56.08c3.224 1.025 5.495 2.199 5.495 4.615 0 2.345-1.759 4.468-5.495 5.201z"
  }));
});
Dollar.displayName = 'Dollar';
export const DollarDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Dollar/Dollar.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Dollar = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M54.284 44.798v-10.11c3.297.807 6.52 2.344 9.157 4.762l.011-.015c.197.157.436.265.708.265.358 0 .665-.173.877-.428l.015.003 4.262-6.008-.01-.005c.175-.202.291-.458.291-.746 0-.34-.153-.638-.387-.849-3.953-3.651-9-5.843-14.924-6.502v-5.806h-.001c0-.637-.516-1.153-1.153-1.153h-4.578c-.637 0-1.153.516-1.153 1.153v5.659c-9.89 1.025-15.75 7.326-15.75 14.725 0 9.963 8.205 12.82 15.75 14.652v11.354c-4.845-.868-8.827-3.379-11.536-6.19-.019-.021-.039-.039-.06-.058l-.052-.051-.008.011a1.134 1.134 0 00-.719-.273 1.14 1.14 0 00-.998.608l-.014-.002-4.125 6.124.005.01a1.133 1.133 0 00-.292.748c0 .367.182.679.448.89l-.011.016c4.029 4.029 9.67 6.959 17.362 7.619v5.44c0 .637.516 1.153 1.153 1.153h4.578c.637 0 1.153-.517 1.153-1.153h.001V75.2c10.769-1.1 16.117-7.398 16.117-15.531 0-10.035-8.498-12.967-16.117-14.871zm-6.886-1.686c-3.003-.951-5.055-2.051-5.055-4.176 0-2.49 1.832-4.248 5.055-4.688v8.864zm6.886 22.784V56.08c3.224 1.025 5.495 2.199 5.495 4.615 0 2.345-1.759 4.468-5.495 5.201z"
  }));
});
Dollar.displayName = 'Dollar';
export var DollarDimensions = {
  height: 100,
  width: 100
};
